1#ifndef __MATH_TENSOR_KERNEL_H__
2#define __MATH_TENSOR_KERNEL_H__
36template<
typename T, const
int N >
52 const int e = elements[
pt];
62 for (
int p = idx; p < nu*nu*nu; p +=
str)
71 for(
int l = 0; l < nu; l++){
82 const int k =
jk /
nv;
86 for(
int l = 0; l < nu; l++){
97 const int k =
jk /
nv;
101 for(
int l = 0; l < nu; l++){
111template<
typename T, const
int N >
134 for (
int p = idx; p < nu*nu*nu; p +=
str)
143 for(
int l = 0; l < nu; l++){
154 const int k =
jk /
nv;
155 const int j =
jk -
k *
nv;
158 for(
int l = 0; l < nu; l++){
169 const int k =
jk /
nv;
170 const int j =
jk -
k *
nv;
173 for(
int l = 0; l < nu; l++){
180template<
typename T, const
int N >
204 for (
int p = idx; p < nu*nu*nu; p +=
str)
213 for(
int l = 0; l < nu; l++){
224 const int k =
jk /
nv;
225 const int j =
jk -
k *
nv;
228 for(
int l = 0; l < nu; l++){
239 const int k =
jk /
nv;
240 const int j =
jk -
k *
nv;
243 for(
int l = 0; l < nu; l++){
__global__ void ale_add_kinematics_kernel(const int n, T *__restrict__ wx, T *__restrict__ wy, T *__restrict__ wz, const T *__restrict__ x_ref, const T *__restrict__ y_ref, const T *__restrict__ z_ref, const T *__restrict__ phi, const T *__restrict__ x, const T *__restrict__ y, const T *__restrict__ z, const kinematics_params_t kin_params)
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ u
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ v
__global__ void tnsr3d_el_kernel(T *__restrict__ v, const int nv, const T *__restrict__ u, const int nu, const T *__restrict__ A, const T *__restrict__ Bt, const T *__restrict__ Ct, const int *elements, const int n_points)
__global__ void tnsr3d_kernel(T *__restrict__ v, const int nv, const T *__restrict__ u, const int nu, const T *__restrict__ A, const T *__restrict__ Bt, const T *__restrict__ Ct)
__global__ void tnsr3d_kernel_large(T *__restrict__ v, const int nv, const T *__restrict__ u, const int nu, const T *__restrict__ A, const T *__restrict__ Bt, const T *__restrict__ Ct)
Fortran bindings to SHMEM's C API.